drawPositionalDepth: Output effective depth plot with effective sequencing depth...

View source: R/libraryQC.R

drawPositionalDepthR Documentation

Output effective depth plot with effective sequencing depth across the tiles for each condition and replicate

Description

Output effective depth plot with effective sequencing depth across the tiles for each condition and replicate

Usage

drawPositionalDepth(covTable, outDir, pdftag)

Arguments

covTable

dataframe with position-specific effective depth at each nucleotide position in each sample

outDir

output directory

pdftag

PDF tag string


jweile/tileseqMave documentation built on April 5, 2024, 4:51 p.m.