nucleotideBiasAnalysis: Helper function to perform nucleotide bias analysis and draw...

View source: R/libraryQC.R

nucleotideBiasAnalysisR Documentation

Helper function to perform nucleotide bias analysis and draw the corresponding plot

Description

Helper function to perform nucleotide bias analysis and draw the corresponding plot

Usage

nucleotideBiasAnalysis(simplifiedMarginal, tile, draw = TRUE)

Arguments

simplifiedMarginal

simplified marginal frequency table

tile

the tile number being analyzed

draw

flag, whether to draw nucleotide bias analysis plot

Value

rates at which each nucelotide is substituted for another across the tile


jweile/tileseqMave documentation built on April 5, 2024, 4:51 p.m.