reachableChanges: Convenience function to calculate the list of SNV-reachable...

View source: R/csvParam2Json.R

reachableChangesR Documentation

Convenience function to calculate the list of SNV-reachable AA changes

Description

Given a parameter object containing a coding sequence, this function will calculate a table of all SNV-reachable amino acid changes, detailing which codon changes correspond to each.

Usage

reachableChanges(params)

Arguments

param

the parameter object

Value

a data.frame containing wt and mutant codons as well as wt and mutant AAs for all possible SNVs


jweile/tileseqMave documentation built on April 5, 2024, 4:51 p.m.