tilesInRegions: Convenience function to find the tiles that belong to each...

View source: R/csvParam2Json.R

tilesInRegionsR Documentation

Convenience function to find the tiles that belong to each region.

Description

Given the parameter object returns a list of vectors containing the tile IDs for each region ID

Usage

tilesInRegions(params)

Arguments

param

the parameter object

Value

a list of vectors containing the tile IDs for each region ID


jweile/tileseqMave documentation built on April 5, 2024, 4:51 p.m.