| drawPositionalDepth | R Documentation |
Output effective depth plot with effective sequencing depth across the tiles for each condition and replicate
drawPositionalDepth(covTable, outDir, pdftag)
covTable |
dataframe with position-specific effective depth at each nucleotide position in each sample |
outDir |
output directory |
pdftag |
PDF tag string |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.