| nucleotideBiasAnalysis | R Documentation |
Helper function to perform nucleotide bias analysis and draw the corresponding plot
nucleotideBiasAnalysis(simplifiedMarginal, tile, draw = TRUE)
simplifiedMarginal |
simplified marginal frequency table |
tile |
the tile number being analyzed |
draw |
flag, whether to draw nucleotide bias analysis plot |
rates at which each nucelotide is substituted for another across the tile
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.