View source: R/csvParam2Json.R
| reachableChanges | R Documentation |
Given a parameter object containing a coding sequence, this function will calculate a table of all SNV-reachable amino acid changes, detailing which codon changes correspond to each.
reachableChanges(params)
param |
the parameter object |
a data.frame containing wt and mutant codons as well as wt and mutant AAs for all possible SNVs
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.